Learn R Programming

COHCAP (version 1.10.0)

COHCAP.avg.by.island: CpG Island Differential Methylation Analysis (Average by Island Workflow).

Description

Provides statistics for CpG islands as well as a list of differentially methylated sites. CpG Island statistics are calculated by averaging beta values among samples per site and comparing the average beta values across groups (considering the pairing between sites).

List of differentially methylated islands will be created in the "CpG_Island" folder. Table of statistics for all CpG islands will be created in the "Raw_Data" folder.

Usage

COHCAP.avg.by.island(sample.file, site.table, beta.table, project.name, project.folder, methyl.cutoff=0.7, unmethyl.cutoff = 0.3, delta.beta.cutoff = 0.2, pvalue.cutoff=0.05, fdr.cutoff=0.05, num.groups=2, num.sites=4, plot.box=TRUE, paired=FALSE, ref="none", output.format = "xls", gene.centric=TRUE)

Arguments

sample.file
Tab-delimited text file providing group attributions for all samples considered for analysis.
beta.table
Data frame with CpG sites in columns (with DNA methylation represented as beta values or percentage methylation), samples in columns, and CpG site annotations are included (in columns 2-5). The COHCAP.annotate function automatically creates this file.
site.table
Data frame with CpG site statistics (one row per CpG site) and CpG site annotations (in columns 2-5). The COHCAP.site function automatically creates this file.
project.name
Name for COHCAP project. This determines the names for output files.
project.folder
Folder for COHCAP output files
methyl.cutoff
Minimum beta or percentage methylation value to be used to define a methylated CpG site. Default is 0.7 (used for beta values), which would correspond to 70 Used for either 1-group or 2-group comparison.
unmethyl.cutoff
Minimum beta or percentage methylation value to be used to define an unmethylated CpG site. Default is 0.3 (used for beta values), which would correspond to 30 Used for either 1-group or 2-group comparison.
delta.beta.cutoff
The minimum absolute value for delta-beta values (mean treatment beta - mean reference beta) to define a differentially methylated CpG site. Only used for 2-group comparison.
pvalue.cutoff
Maximum p-value allowed to define a site as differentially methylated. Used only for comparisons with at least 2 groups (with 3 replicates per group)
fdr.cutoff
Maximum False Discovery Rate (FDR) allowed to define a site as differentially methylated. Used only for comparisons with at least 2 groups (with 3 replicates per group)
num.groups
Number of groups described in sample description file. COHCAP algorithm differs when analysing 1-group, 2-group, or >2-group comparisons. COHCAP cannot currently analyze continuous phenotypes.
num.sites
Minimum number of differentially methylated sites to define a differentially methylated CpG island.
ref
Reference group used to define baseline methylation levels. Only used for 2-group comparison
plot.box
A logical value: Should box-plots be created to visualize CpG island differential methylation?
paired
A logical value: Is there any special pairing between samples in different groups? If so, the pairing variable must be specified in the 3rd column of the sample description file. Used for p-value calculation, so this only applies to comparisons with at least 2 groups.
output.format
Format for output tables: 'xls' for Excel file, 'txt' for tab-delimited text file
gene.centric
Should CpG islands not mapped to genes be ignored? Default: TRUE (Recommended setting for integration with gene expession data)

Value

Data frame of average beta (or percentage methylation) values across differentially methylated sites within a differentially methylated CpG island.. This data frame can be used for integration analysis.

See Also

COHCAP Discussion Group: http://sourceforge.net/p/cohcap/discussion/general/

Examples

Run this code
library("COHCAP")

dir <- system.file("extdata", package="COHCAP")
beta.file <- file.path(dir,"GSE42308_truncated.txt")
sample.file <- file.path(dir,"sample_GSE42308.txt")
project.folder <- getwd()
project.name <- "450k_avg_by_island_test"

beta.table <- COHCAP.annotate(beta.file, project.name, project.folder,
				platform="450k-UCSC")
filtered.sites <- COHCAP.site(sample.file, beta.table, project.name,
				project.folder, ref="parental")
filtered.islands <- COHCAP.avg.by.island(sample.file, filtered.sites,
				beta.table, project.name, project.folder, ref="parental")

Run the code above in your browser using DataLab