Learn R Programming

COHCAP (version 1.10.0)

COHCAP.qc: DNA Methylation Quality Control Statistics

Description

Provides descriptive statistics (median, top/bottom quartiles, mininum,maximum), sample histograms, sample dendrogram, principal component analysis plot.

Output files will be created in the "QC" subfolder.

Usage

COHCAP.qc(sample.file, beta.table, project.name, project.folder, plot.legend=TRUE, color.palette = c("red","blue", "green","orange","purple","cyan","pink","maroon", "yellow","grey","black",colors()))

Arguments

sample.file
Tab-delimited text file providing group attributions for all samples considered for analysis.
beta.table
Data frame with CpG sites in columns (with DNA methylation represented as beta values or percentage methylation), samples in columns, and CpG site annotations are included (in columns 2-5). The COHCAP.annotate function automatically creates this file.
project.name
Name for COHCAP project. This determines the names for output files.
project.folder
Folder for COHCAP output files
plot.legend
A logical value: Should legend be plotted within QC figures?
color.palette
Colors for primary variable (specified in the second column of the sample file). Remember, COHCAP can only analyze discrete variables categoried with groups (preferably with replicates).

See Also

COHCAP Discussion Group: http://sourceforge.net/p/cohcap/discussion/general/

Examples

Run this code
library("COHCAP")

dir <- system.file("extdata", package="COHCAP")
beta.file <- file.path(dir,"GSE42308_truncated.txt")
sample.file <- file.path(dir,"sample_GSE42308.txt")
project.folder <- getwd()
project.name <- "450k_test"

beta.table <- COHCAP.annotate(beta.file, project.name, project.folder,
				platform="450k-UCSC")
COHCAP.qc(sample.file, beta.table, project.name, project.folder)

Run the code above in your browser using DataLab