Usage
COHCAP.qc(sample.file, beta.table, project.name, project.folder,
plot.legend=TRUE, color.palette = c("red","blue",
"green","orange","purple","cyan","pink","maroon",
"yellow","grey","black",colors()))
Arguments
sample.file
Tab-delimited text file providing group attributions for all samples considered for analysis.
beta.table
Data frame with CpG sites in columns (with DNA methylation represented as beta values or percentage methylation),
samples in columns, and CpG site annotations are included (in columns 2-5).
The COHCAP.annotate function automatically creates this file.
project.name
Name for COHCAP project. This determines the names for output files.
project.folder
Folder for COHCAP output files
plot.legend
A logical value: Should legend be plotted within QC figures?
color.palette
Colors for primary variable (specified in the second column of the sample file).
Remember, COHCAP can only analyze discrete variables categoried with groups (preferably with replicates).